@@ -3,5 +3,5 @@ import Options
 
 
 if __name__ == '__main__':
-	sequencer = Options.get_sequencer()
+	sequencer = Options.get_sequencer_from_cli()
 	sequencer.play()
