@@ -2,5 +2,6 @@ from RockDrum import RockDrum
 from JazzDrum import JazzDrum
 from BlastBeat import BlastBeat
 from Metronome import Metronome
+from Snare import Snare
 
-__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome']
+__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare']
